summaryrefslogtreecommitdiff
path: root/apps/confbridge/include/confbridge.h
diff options
context:
space:
mode:
authorKinsey Moore <kmoore@digium.com>2013-05-31 12:41:10 +0000
committerKinsey Moore <kmoore@digium.com>2013-05-31 12:41:10 +0000
commit39d5e40cd58c25f80759d1be9e5df945cf4e1da1 (patch)
treea342e9e8edf3816b4f2ca40fed09cb7b7cde9082 /apps/confbridge/include/confbridge.h
parente1bff7958adbf7780a70fd6e687e344edf11fdcc (diff)
Remove remnant of snapshot blob JSON types
Remove usage of the once-mandatory snapshot blob type field, refactor confbridge stasis messages accordingly, and remove ast_bridge_blob_json_type(). Review: https://reviewboard.asterisk.org/r/2575/ git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@390250 65c4cc65-6c06-0410-ace0-fbb531ad65f3
Diffstat (limited to 'apps/confbridge/include/confbridge.h')
-rw-r--r--apps/confbridge/include/confbridge.h78
1 files changed, 75 insertions, 3 deletions
diff --git a/apps/confbridge/include/confbridge.h b/apps/confbridge/include/confbridge.h
index f0620149a..1af621dd8 100644
--- a/apps/confbridge/include/confbridge.h
+++ b/apps/confbridge/include/confbridge.h
@@ -465,12 +465,84 @@ int conf_add_post_join_action(struct confbridge_user *user, int (*func)(struct c
/*!
* \since 12.0
* \brief get the confbridge stasis message type
*
* \retval stasis message type for confbridge messages if it's available
* \retval NULL if it isn't
*/
-struct stasis_message_type *confbridge_message_type(void);
+struct stasis_message_type *confbridge_start_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge end stasis message type
+ *
+ * \retval stasis message type for confbridge end messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_end_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge join stasis message type
+ *
+ * \retval stasis message type for confbridge join messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_join_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge leave stasis message type
+ *
+ * \retval stasis message type for confbridge leave messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_leave_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge start_record stasis message type
+ *
+ * \retval stasis message type for confbridge start_record messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_start_record_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge stop_record stasis message type
+ *
+ * \retval stasis message type for confbridge stop_record messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_stop_record_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge mute stasis message type
+ *
+ * \retval stasis message type for confbridge mute messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_mute_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge unmute stasis message type
+ *
+ * \retval stasis message type for confbridge unmute messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_unmute_type(void);
+
+/*!
+ * \since 12.0
+ * \brief get the confbridge talking stasis message type
+ *
+ * \retval stasis message type for confbridge talking messages if it's available
+ * \retval NULL if it isn't
+ */
+struct stasis_message_type *confbridge_talking_type(void);
/*!
* \since 12.0
@@ -465,12 +465,84 @@ int conf_add_post_join_action(struct confbridge_user *user, int (*func)(struct c
/*!
* \since 12.0
- * \brief get the confbridge stasis message type
+ * \brief get the confbridge start stasis message type
*
@@ -465,12 +465,84 @@ int conf_add_post_join_action(struct confbridge_user *user, int (*func)(struct c
*
- * \retval stasis message type for confbridge messages if it's available
+ * \retval stasis message type for confbridge start messages if it's available
* \retval NULL if it isn't
*/